==> lm_sensors-1.3.0.tgz: lm_sensors-1.3.0/main.h <==
/*
    main.h - Header file for the Linux sensor programs
    Copyright (c) 1997, 1998  Alexander Larsson <alla@lysator.liu.se>,
    Frodo Looijaard <frodol@dds.nl> and Philip Edelbrock <phil@netroedge.com>.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/* This file contains all external definition used throughout the module
   sources, as well as several compatibility macro's for older kernels. */

#ifndef LM78_MAIN_H
#define LM78_MAIN_H

#include <linux/types.h>
#include <asm/semaphore.h>

/* This useful macro is not defined in the 2.0 kernels */
#ifndef KERNEL_VERSION
#define KERNEL_VERSION(a,b,c) (((a) << 16) + ((b) << 8) + (c))
#endif

/* In lm75.c */
extern int LM75_Init(void);
extern void LM75_Cleanup(void);
extern int LM75_Print_Values (char *buf);
extern void LM75_Update_Values(void);

/* In lm78.c */
extern int LM78_Init(void);
extern void LM78_Cleanup(void);
extern int LM78_Print_Values (char *buf);
extern void LM78_Update_Values(void);
extern void LM78_Set(int what, int nr, long value);
extern long LM78_Get(int what, int nr);

/* In sysctl.c */
extern int LM_Sysctl_Init(void);
extern void LM_Sysctl_Cleanup(void);

/* In main.c */
extern void LM_Update_Data(void);

struct lm75_data {
  int address;
  int temp;

#ifdef DEBUG
  int config;
#endif
  int temphyst;
  int tempos;

};

#define MAX_LM75 8
#define LM75_NOT_PRESENT 0xffff

struct LM_Sensor_Data {

  unsigned long last_read;

  u8 in[7];
  u8 in_max[7];
  u8 in_min[7];

  u8 vid;

  u8 temp_mb;
  u8 temp_mb_max;
  u8 temp_mb_min;

  u8 interrupt_status[2];
  
  u8 fan[3];
  u8 fan_min[3];
  
  int valid;

  struct lm75_data lm75 [MAX_LM75];

#ifdef DEBUG
  int lm78_smbus_addr;
#endif
  
};

extern struct semaphore LM_Sensor_Data_Sem;
extern struct LM_Sensor_Data LM_Sensor_Data;


#endif /* LM78_MAIN_H */

==> lm_sensors-1.3.3pre.tgz: lm_sensors-1.3.3pre/main.h <==
/*
    main.h - Header file for the Linux sensor programs
    Copyright (c) 1997, 1998  Alexander Larsson <alla@lysator.liu.se>,
    Frodo Looijaard <frodol@dds.nl> and Philip Edelbrock <phil@netroedge.com>.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/* This file contains all external definition used throughout the module
   sources, as well as several compatibility macro's for older kernels. */

#ifndef LM78_MAIN_H
#define LM78_MAIN_H

#include <linux/types.h>
#include <asm/semaphore.h>

/* This useful macro is not defined in the 2.0 kernels */
#ifndef KERNEL_VERSION
#define KERNEL_VERSION(a,b,c) (((a) << 16) + ((b) << 8) + (c))
#endif

/* In lm75.c */
EXTERN int LM75_Init (void);
EXTERN void LM75_Cleanup (void);
EXTERN int LM75_Print_Values (char *buf);
EXTERN void LM75_Update_Values (void);
EXTERN void LM75_Set(int what, int nr, long value);
EXTERN long LM75_Get(int what, int nr);


/* In lm78.c */
EXTERN int LM78_Init(void);
EXTERN void LM78_Cleanup(void);
EXTERN int LM78_Print_Values (char *buf);
EXTERN void LM78_Update_Values(void);
EXTERN void LM78_Set(int what, int nr, long value);
EXTERN long LM78_Get(int what, int nr);

/* In sysctl.c */
EXTERN int LM_Sysctl_Init(void);
EXTERN void LM_Sysctl_Cleanup(void);

/* In main.c */
EXTERN void LM_Update_Data(void);

struct lm75_data {
  int address;
  int temp;

#ifdef DEBUG
  int config;
#endif
  int temphyst;
  int tempos;

};

#define MAX_LM75 8
#define LM75_NOT_PRESENT 0xffff

struct LM_Sensor_Data {

  unsigned long last_read;

  u8 in[7];
  u8 in_max[7];
  u8 in_min[7];

  u8 vid;

  u8 temp_mb;
  u8 temp_mb_max;
  u8 temp_mb_min;

  u8 interrupt_status[2];
  
  u8 fan[3];
  u8 fan_min[3];
  
  int valid;

  struct lm75_data lm75 [MAX_LM75];

#ifdef DEBUG
  int lm78_smbus_addr;
#endif
  
};

EXTERN struct semaphore LM_Sensor_Data_Sem;
EXTERN struct LM_Sensor_Data LM_Sensor_Data;


/* copy_from/to_usr is called memcpy_from/to_fs in 2.0 kernels; perhaps in
   some early 2.1 kernels too? */
#if (LINUX_VERSION_CODE < KERNEL_VERSION(2,1,0))
#define copy_from_user memcpy_fromfs
#define copy_to_user memcpy_tofs
#endif

#endif /* LM78_MAIN_H */
